--- a/setup.py
+++ b/setup.py
@@ -1,6 +1,7 @@
 # setup.py
 from distutils.core import setup
-import py2exe
+# Must comment out before patching (CUS)
+#import py2exe
 import spglobalfuncs
 
 setup(name="SixPACK",
